"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var app = require("tns-core-modules/application");
function isLoggedIn(fetchUserData) {
    return new Promise(function (resolve, reject) {
        var loggedIn = com.snapchat.kit.sdk.SnapLogin.isUserLoggedIn(app.android.foregroundActivity || app.android.startActivity);
        if (loggedIn && fetchUserData) {
            getUserData(resolve, reject);
        }
        else {
            resolve(loggedIn);
        }
    });
}
exports.isLoggedIn = isLoggedIn;
function login(fetchUserData) {
    return new Promise(function (resolve, reject) {
        var onLoginStateChangedListener = new com.snapchat.kit.sdk.core.controller.LoginStateController.OnLoginStateChangedListener({
            onLoginSucceeded: function () {
                if (fetchUserData) {
                    getUserData(resolve, reject);
                }
                else {
                    resolve();
                }
            },
            onLoginFailed: function () {
                reject();
            },
            onLogout: function () {
                console.log(">> onLogout");
            }
        });
        com.snapchat.kit.sdk.SnapLogin.getLoginStateController(app.android.foregroundActivity || app.android.startActivity).addOnLoginStateChangedListener(onLoginStateChangedListener);
        com.snapchat.kit.sdk.SnapLogin.getAuthTokenManager(app.android.foregroundActivity || app.android.startActivity).startTokenGrant();
    });
}
exports.login = login;
function logout() {
    return new Promise(function (resolve, reject) {
        console.log(com.snapchat.kit.sdk.SnapLogin.getAuthTokenManager(app.android.foregroundActivity || app.android.startActivity).revokeToken());
        // SCSDKLoginClient.unlinkCurrentSessionWithCompletion(loggedOut => resolve(loggedOut))
        resolve();
    });
}
exports.logout = logout;
function getUserData(resolve, reject) {
    var query = "{me{displayName, bitmoji{avatar}, externalId}}";
    var fetchUserDataCallbackHandler = new org.nativescript.plugins.snapkit.login.TNSFetchUserDataCallbackHandler({
        onLoginSuccess: function (response /* com.snapchat.kit.sdk.login.models.UserDataResponse */) {
            console.log(">> onLoginSuccess: " + response);
            if (response && response.getData()) {
                var me = response.getData().getMe();
                if (me === null) {
                    reject("Failed to get userdata");
                    return;
                }
                resolve({
                    displayName: me.getDisplayName(),
                    externalId: me.getExternalId(),
                    avatar: me.getBitmojiData().getAvatar(),
                });
            }
        },
        onLoginFailure: function (isNetworkError, statusCode) {
            console.log(">> onLoginFailure, isNetworkError: " + isNetworkError);
            console.log(">> onLoginFailure, statusCode: " + statusCode);
            reject(statusCode);
        }
    });
    com.snapchat.kit.sdk.SnapLogin.fetchUserData(app.android.foregroundActivity || app.android.startActivity, query, null, new org.nativescript.plugins.snapkit.login.TNSFetchUserDataCallback(fetchUserDataCallbackHandler));
}
